#
# spec file for package python-zope.proxy
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2013 LISA GmbH, Bingen, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-zope.proxy%{psuffix}
VCS: https://src.suse.de/SLFO-pool/python-zope.proxy#626d5358a012b37c1241628ee9f8b4febe4f173127f48a00ac37af71714fa212
Version:        6.1
Release:        160000.2.2
Summary:        Generic Transparent Proxies
License:        ZPL-2.1
Group:          Development/Languages/Python
URL:            https://github.com/zopefoundation/zope.proxy
Source:         https://files.pythonhosted.org/packages/source/z/zope.proxy/zope_proxy-%{version}.tar.gz
BuildRequires:  %{python_module devel >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-zope.interface
%if %{with test}
BuildRequires:  %{python_module zope.security}
BuildRequires:  %{python_module zope.testrunner}
%endif
Conflicts:      python-zope-proxy < %{version}
%python_subpackages

%description
Proxies are special objects which serve as mostly-transparent wrappers around
another object, intervening in the apparent behavior of the wrapped object only
when necessary to apply the policy (e.g., access checking, location brokering,
etc.) for which the proxy is responsible.

%package        devel
Summary:        Generic Transparent Proxies
Group:          Development/Languages/Python
Requires:       %{name} = %{version}
Provides:       python-zope-proxy = %{version}
Obsoletes:      python-zope-proxy < %{version}

%description    devel
This package contains the files needed for binding the %{name} C module.

%prep
%autosetup -p1 -n zope_proxy-%{version}
rm -rf zope.proxy.egg-info

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%{python_expand rm %{buildroot}%{$python_sitearch}/zope/proxy/_zope_proxy_proxy.c
  %fdupes %{buildroot}%{$python_sitearch}
}
%endif

%if %{with test}
%check
%python_expand PYTHONPATH=src %{_bindir}/zope-testrunner-%{$python_bin_suffix} -vvv --test-path src
%endif

%if !%{with test}
%files %{python_files}
%license LICENSE.txt
%doc COPYRIGHT.txt CHANGES.rst README.rst
%exclude %{python_sitearch}/zope/proxy/proxy.h
%{python_sitearch}/zope/proxy
%{python_sitearch}/zope.proxy-%{version}-py*-nspkg.pth
%{python_sitearch}/zope[_.]proxy-%{version}.dist-info

%files %{python_files devel}
%dir %{python_sysconfig_path include}/zope_proxy
%{python_sysconfig_path include}/zope_proxy/*
%{python_sitearch}/zope/proxy/proxy.h
%endif

%changelog
* Tue Apr  1 2025 mmachova@suse.com
- Make it compatible with older setuptools
* Fri Mar 28 2025 steven.kowalik@suse.com
- Normalize metadata directory name.
- Normalize include directory name.
* Mon Oct 28 2024 dmueller@suse.com
- update to 6.1:
  * Respect PURE_PYTHON environment variable set to 0.
  * Declare full support for Python 3.13.
  * Drop support for Python 3.7.
  * Build Windows wheels on GHA.
  * Correct return type for wrap_hash (fixes build on i386).
* Wed Mar 13 2024 dmueller@suse.com
- update to 5.2:
  * Add preliminary support for Python 3.13 as of 3.13a3.
* Sat Dec 16 2023 dmueller@suse.com
- update to 5.1:
  * Add support for Python 3.12.
  * Drop support for Python 2.7, 3.5, 3.6.
  * Remove proxying code for names that no longer exist in Python
    3 like ``__long__`` and some others.
* Fri Jun  9 2023 ecsos@opensuse.org
- Add %%{?sle15_python_module_pythons}
* Mon Dec  5 2022 yarunachalam@suse.com
- Update to version 4.6.1
  * Add support for building arm64 wheels on macOS.
* Wed Nov  9 2022 yarunachalam@suse.com
- Update to version 4.6.0
  * Add support for Python 3.11.
* Sat Oct 29 2022 yarunachalam@suse.com
- Update to version 4.5.1
  * Disable unsafe math optimizations in C code. See pull request 53.
* Tue Oct 11 2022 yarunachalam@suse.com
- Update to version 4.5.0 (2021-11-17)
  * Add support for Python 3.10.
* Wed Jan 13 2021 code@bnavigator.de
- Let the python-rpm-macros automatically figure out the correct
  provides and obsoletes for the flavor
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 4.3.5
  - Stop installing C header files on PyPy (which is what zope.proxy before 4.3.4
    used to do), fixes `issue 39
    <https://github.com/zopefoundation/zope.proxy/issues/39>`_.
* Mon Mar 16 2020 pgajdos@suse.com
- version update to 4.3.4
  - Fix a compilation warning on Python 3.8. The slot ``tp_print``
    changed to ``tp_vectorcall_offset`` in 3.8 and must not be set.
    Prior to 3.8, it was reserved and ignored in all Python 3 versions.
    See `issue 36
    <https://github.com/zopefoundation/zope.proxy/issues/36>`_.
  - Remove deprecated use of setuptools features.  See `issue 38
    <https://github.com/zopefoundation/zope.proxy/issues/38>`_.
* Tue Jan 21 2020 mcalabkova@suse.com
- update to 4.3.3
  * Add support for Python 3.8.
  * Drop support for Python 3.4.
* Mon Jul 22 2019 tchvatal@suse.com
- Update to 4.3.2:
  * Fix error handling in ProxyBase.__setattr__: any the exception raised by
    PyString_AsString/PyUnicode_AsUTF8 would be silently swallowed up and ignored. See issue 31.
* Fri Apr  5 2019 mcalabkova@suse.com
- update to version 4.3.1
  * Add support for Python 3.7.
  * Simplify the internal C handling of attribute names.
  * Make building the C extension optional.
  4.3.0
  * Fix a potential rare crash when deallocating proxies.
  * Drop support for Python 3.3.
  * Drop support for “python setup.py test”.
  * 100%% test coverage.
  * Fix indexing pure-Python proxies with slices under Python 3,
    and restore the use of __getslice__ (if implemented by the
    target’s type) under Python 2.
- drop *-doc subpackage, use multibuild instead
* Fri Sep 22 2017 toddrme2178@gmail.com
- Still need to conflict with python3-zopy-proxy.
* Mon Sep 18 2017 toddrme2178@gmail.com
- Provides/Obsoletes should be on the -devel package since
  python3-zope-proxy has the devel files.
* Thu Sep  7 2017 toddrme2178@gmail.com
- Fix conflicts with python3-zope-proxy
* Thu Jul 13 2017 aloisio@gmx.com
- Update to version 4.2.1
  * Make the pure-Python implementation of sameProxiedObjects handle
    zope.security proxies. See issue 15.
  * Add support for Python 3.6.
  4.2.0:
  * Correctly strip zope.security proxies in removeAllProxies.
    See issue 13.
  * Avoid poisoning the user’s global wheel cache when testing
    PURE_PYTHON environments under tox,
  * Drop support for Python 2.6 and 3.2.
  * Add support for Python 3.5.
  4.1.6:
  * Make subclasses of ProxyBase properly delegate __module__ to the
    wrapped object. This fixes some zope.interface lookups under
    PyPy.
  * Make the pure-Python implementation of ProxyBase properly report
    the zope.interface interfaces implemented by builtin types like
    list. This fixes some zope.interface lookups under PyPy.
  4.1.5:
  * Make the C implementation proxy __unicode__ correctly.
  * Make the C implementation use the standard methods to proxy int
    and float.
  * Make the pure Python implementation handle descriptors defined
    in subclasses like the C version.
    See https://github.com/zopefoundation/zope.proxy/issues/5.
- Split docs and tests into separate -doc package since running
  tests and sometimes building docs had become very messy.
  Also see (gh#/zopefoundation/zope.proxy#18)
- Converted to single-spec
* Fri May 15 2015 benoit.monin@gmx.fr
- update to version 4.1.4:
  * Added support for Python 3.4.
  * Updated bootstrap.py to version 2.2.
- point the source URL to pypi
- pass -q to test to avoid spamming the build log
* Mon Jul 29 2013 hpj@urpla.net
- version 4.1.3: initial build
